@@ -3,7 +3,7 @@ package RPi::ADC::ADS;
 use strict;
 use warnings;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 require XSLoader;
 XSLoader::load('RPi::ADC::ADS', $VERSION);
@@ -106,9 +106,13 @@ my %gain = (
     7 => 0xE00, # 00001110, 3584
 );
 
+# map of all the above config register maps
+
+my $param_map;
+
 BEGIN {
 
-    my $param_map = {
+    $param_map = {
         channel  => \%mux,
         queue    => \%queue,
         polarity => \%polarity,
@@ -126,7 +130,7 @@ BEGIN {
             my ($self, $opt) = @_;
 
             if (defined $opt) {
-                if (!exists $param_map->{$sub}{$opt}) {
+                if (! exists $param_map->{$sub}{$opt}) {
                     die "$sub param requires an integer\n";
                 }
                 $self->{$sub} = $param_map->{$sub}{$opt};
@@ -135,7 +139,7 @@ BEGIN {
             my $default = "DEFAULT_" . uc $sub;
             my $max     = "MAX_"     . uc $sub;
 
-            $self->{$sub} = __PACKAGE__->$default if !defined $self->{$sub};
+            $self->{$sub} = __PACKAGE__->$default if ! defined $self->{$sub};
             $self->_bit_set($self->{$sub}, __PACKAGE__->$max);
             return $self->{$sub};
         }
@@ -272,34 +276,6 @@ sub _bit_set {
 
     $self->register($msb, $lsb);
 }
-sub _lsb {
-    # least significant byte of config register
-
-    my ($self, $lsb) = @_;
-
-    if (defined $lsb){
-        if (! grep {$lsb == $_} (0..255)){
-            die "_lsb() requires an int 0..255\n";
-        }
-        my $msb = $self->register->[0];
-        $self->register($msb, $lsb);
-    }
-    return $self->register->[1];
-}
-sub _msb {
-    # most significant byte of config register
-
-    my ($self, $msb) = @_;
-
-    if (defined $msb){
-        if (! grep {$msb == $_} (0..255)){
-            die "_msb() requires an int 0..255\n";
-        }
-        my $lsb = $self->register->[1];
-        $self->register($msb, $lsb);
-    }
-    return $self->register->[0];
-}
 sub _register_data {
 
     # for testing/validation purposes
@@ -754,6 +730,10 @@ Element C<1> is a byte long, and represents the most significant bits (15-8) of
 each 16-bit register, while element C<2> represents the least significant bits,
 7-0.
 
+It is advised that you don't change any of these except for the input channels
+unless you know how the hardware works, and you have a good understanding of the
+specific configuration register options.
+
 =head2 CONFIG REGISTER
 
 =head3 CONVERSATION BIT
@@ -761,18 +741,18 @@ each 16-bit register, while element C<2> represents the least significant bits,
 Bit: 15
 
 This bit should always be set to C<1> when writing. This initiates a
-conversation ADC. When reading, this bit will read C<1> if a conversion is
-currently occuring, and C<0> if the current conversion is complete.
+conversation with the ADC. When reading, this bit will read C<1> if a conversion
+is currently occuring, and C<0> if the current conversion is complete.
 
 =head3 INPUT CHANNELS
 
 Bit: 14-12
 
 Represents the ADC input channel, as well as either a single-ended
-(difference between HIGH and GRD) or differential mode (difference between
-two input channels).
+(difference between a single input channel and GRD) or differential mode
+(difference between two input channels).
 
-Single mode configuration (with the alternate parameter values):
+Single mode configuration:
 
     Param   Value   Input
     ---------------------
@@ -816,7 +796,7 @@ Represents the programmable gain amplifier. This software uses C<1> or
 
 Bit: 8
 
-Represents the conversion operation mode. We use single conversion hardware
+Represents the conversion operation mode. We use the single conversion hardware
 default.
 
     Param/Value   Mode
@@ -859,7 +839,7 @@ Represents the comparator polarity. We use C<0> (active low) by default.
 
 Bit: 1-0
 
-Represents the comparator queue. C<3> (disabled) by default.
+Represents the comparator queue. We use C<3> (disabled) by default.
 
     Param   Value   Queue
     ---------------------
@@ -874,7 +854,7 @@ Represents the comparator queue. C<3> (disabled) by default.
 Each channel has a conversion register (that contains the actual analog input).
 This register is 16 bits wide. With that said, the most significant bit is used
 to identify whether the number is positive or negative, so technically, for the
-ADC1xxx series ADCs, the width is actually 15 bits, and the ADC10xx units are
+ADC11xx series ADCs, the width is actually 15 bits, and the ADC10xx units are
 11 bits wide (as the resolution on these models are only 12-bit as opposed to
 16-bit).
 
